@@ -8,7 +8,7 @@ use warnings;
 use Module::Load;
 use SHARYANTO::Package::Util qw(package_exists);
 
-our $VERSION = '1.31'; # VERSION
+our $VERSION = '1.32'; # VERSION
 
 require Exporter;
 our @ISA       = qw(Exporter);
@@ -25,7 +25,8 @@ sub dux {
 
     my $pkg = "Data::Unixish::$f";
     load $pkg unless package_exists($pkg);
-    my $fn = "Data::Unixish::$f\::$f";
+    my $fleaf = $f; $fleaf =~ s/.+:://;
+    my $fn = "Data::Unixish::$f\::$fleaf";
     die "Subroutine &$fn not defined" unless defined &$fn;
 
     no strict 'refs';
@@ -47,13 +48,15 @@ sub dux {
 __END__
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Data::Unixish::List - Apply dux function to a list (and return the result as a list)
 
 =head1 VERSION
 
-version 1.31
+version 1.32
 
 =head1 SYNOPSIS
 
@@ -84,6 +87,9 @@ the first element is the dux function name and the second element contains the
 arguments for the function. If you do not need to pass any arguments/options to
 the dux function, you can use the simpler string version.
 
+
+None are exported by default, but they are exportable.
+
 =head1 SEE ALSO
 
 L<Data::Unixish::Apply>
