@@ -8,7 +8,7 @@ use warnings;
 
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.31'; # VERSION
+our $VERSION = '1.32'; # VERSION
 
 our %SPEC;
 
@@ -54,13 +54,15 @@ sub ltrim {
 __END__
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Data::Unixish::ltrim - Strip whitespace at the beginning of each line of text
 
 =head1 VERSION
 
-version 1.31
+version 1.32
 
 =head1 SYNOPSIS
 
@@ -87,12 +89,34 @@ This software is copyright (c) 2013 by Steven Haryanto.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 DESCRIPTION
+
 =head1 FUNCTIONS
 
 
-=head2 ltrim() -> [status, msg, result, meta]
+None are exported by default, but they are exportable.
 
-No arguments.
+=head2 ltrim(%args) -> [status, msg, result, meta]
+
+Strip whitespace at the beginning of each line of text.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<in> => I<any>
+
+Input stream (e.g. array or filehandle).
+
+=item * B<out> => I<any>
+
+Output stream (e.g. array or filehandle).
+
+=item * B<strip_newline> => I<bool> (default: 0)
+
+Whether to strip newlines at the beginning of text.
+
+=back
 
 Return value:
 
