@@ -7,7 +7,7 @@ use warnings;
 #use Log::Any '$log';
 
 use Data::Unixish::Util qw(%common_args);
-our $VERSION = '1.31'; # VERSION
+our $VERSION = '1.32'; # VERSION
 
 our %SPEC;
 
@@ -35,7 +35,6 @@ sub yes {
     my ($in, $out) = ($args{in}, $args{out});
 
     my $str = $args{string} // 'y';
-    $str .= "\n" unless $str =~ /\n\z/;
 
     while (1) {
         push @$out, $str;
@@ -52,13 +51,15 @@ sub yes {
 __END__
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Data::Unixish::yes - Output a string repeatedly until killed
 
 =head1 VERSION
 
-version 1.31
+version 1.32
 
 =head1 SYNOPSIS
 
@@ -81,12 +82,34 @@ This software is copyright (c) 2013 by Steven Haryanto.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 DESCRIPTION
+
 =head1 FUNCTIONS
 
 
-=head2 yes() -> [status, msg, result, meta]
+None are exported by default, but they are exportable.
 
-No arguments.
+=head2 yes(%args) -> [status, msg, result, meta]
+
+Output a string repeatedly until killed.
+
+This is like the Unix C<yes> utility.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<in> => I<any>
+
+Input stream (e.g. array or filehandle).
+
+=item * B<out> => I<any>
+
+Output stream (e.g. array or filehandle).
+
+=item * B<string> => I<str> (default: "y")
+
+=back
 
 Return value:
 
